@@ -36,7 +36,11 @@ KDateTime::Spec getTimeSpec(bool isUtc, const std::string& timezone)
         return  KDateTime::Spec(KDateTime::ClockTime);
     }
     //Timezone
-    KTimeZone tz = KSystemTimeZones::zone(QString::fromStdString(timezone)); //Needs ktimezoned (timezone daemon running) http://api.kde.org/4.x-api/kdelibs-apidocs/kdecore/html/classKSystemTimeZones.html
+
+    //Convert non-olson timezones if necessary
+    const QString normalizedTz = TimezoneConverter::normalizeTimezone(QString::fromStdString(timezone));
+    Debug() << "normalized " << normalizedTz;
+    KTimeZone tz = KSystemTimeZones::zone(normalizedTz); //Needs ktimezoned (timezone daemon running) http://api.kde.org/4.x-api/kdelibs-apidocs/kdecore/html/classKSystemTimeZones.html
     if (!tz.isValid()) {
         Error() << "timezone not found" << QString::fromStdString(timezone);
         if (!KSystemTimeZones::isTimeZoneDaemonAvailable()) {
@@ -161,4 +165,5 @@ std::string fromMailto(const QUrl &mailtoUri, std::string &name)
 }
 
     }
-}
\ No newline at end of file
+}
+
