@@ -18,17 +18,37 @@
 #ifndef KOLABCOMMONCONVERSION_H
 #define KOLABCOMMONCONVERSION_H
 
-#include <KDE/KDateTime>
+#include "kolab_export.h"
+
+#include <kdatetime.h>
 #include <QStringList>
-#include <kolab/kolabcontainers.h>
+#include <kolabcontainers.h>
 
 
 namespace Kolab {
     namespace Conversion {
-        KDateTime toDate(const Kolab::cDateTime &dt);
-        cDateTime fromDate(const KDateTime &dt);
+        KOLAB_EXPORT KDateTime toDate(const Kolab::cDateTime &dt);
+        KOLAB_EXPORT cDateTime fromDate(const KDateTime &dt);
         QStringList toStringList(const std::vector<std::string> &l);
         std::vector<std::string> fromStringList(const QStringList &l);
+        /**
+         * Returns a UTC, Floating Time or Timezone
+         */
+        KDateTime::Spec getTimeSpec(bool isUtc, const std::string &timezone);
+
+        QUrl toMailto(const std::string &email, const std::string &name = std::string());
+        std::string fromMailto(const QUrl &mailtoUri, std::string &name);
+        
+        inline std::string toStdString(const QString &s)
+        {
+            return std::string(s.toUtf8().constData());
+        }
+
+        inline QString fromStdString(const std::string &s)
+        {
+            return QString::fromUtf8(s.c_str());
+        }
+
     };
 };
 
