@@ -20,7 +20,7 @@
 
 #include "kolab_export.h"
 
-#include <kolab/kolabcontact.h>
+#include <kolabcontact.h>
 #include <kabc/addressee.h>
 #include <kabc/contactgroup.h>
 
@@ -40,4 +40,4 @@ namespace Kolab {
     };
 };
 
-#endif
\ No newline at end of file
+#endif
