@@ -20,7 +20,7 @@
 
 #include "kolab_export.h"
 
-#include <kolab/kolabnote.h>
+#include <kolabnote.h>
 #include <kmime/kmime_message.h>
 
 namespace Kolab {
@@ -36,4 +36,4 @@ namespace Kolab {
     };
 };
 
-#endif
\ No newline at end of file
+#endif
